| Title: | Design and Analysis of Order-of-Addition Mixture Experiments |
|---|---|
| Description: | A facility to generate various classes of fractional designs for order-of-addition experiments namely fractional order-of-additions orthogonal arrays, see Voelkel, Joseph G. (2019). "The design of order-of-addition experiments." Journal of Quality Technology 51:3, 230-241, <doi:10.1080/00224065.2019.1569958>. Provides facility to construct component orthogonal arrays, see Jian-Feng Yang, Fasheng Sun and Hongquan Xu (2020). "A Component Position Model, Analysis and Design for Order-of-Addition Experiments." Technometrics, <doi:10.1080/00401706.2020.1764394>. Supports generation of fractional designs for order-of-addition mixture experiments. Analysis of data from order-of-addition mixture experiments is also supported. |
| Authors: | Muhsina A [aut], Baidya Nath Mandal [cre, ctb], Rajender Parsad [ctb], Sukanta Dash [ctb], Kaushal Kumar Yadav [ctb] |
| Maintainer: | Baidya Nath Mandal <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-04-11 05:28:00 UTC |
| Source: | https://github.com/cran/mixOofA |
construct a component orthogonal array with m components
COA(m)COA(m)
m |
a positive integer, should be prime or prime power |
a component orthogonal array with m components
COA(5)COA(5)
Compute D-efficiency from PWO matrix of a given design for order-of-addition experiments
D_effi_pwo(X)D_effi_pwo(X)
X |
PWO matrix of a design for order-of-addition experiments |
D-efficiency
design <- matrix(c(4,2,3,1, 4,1,3,2, 3,4,2,1, 3,4,1,2, 3,2,1,4, 3,1,2,4, 2,4,3,1, 2,4,1,3, 2,1,3,4, 1,4,3,2, 1,4,2,3, 1,2,3,4), 12, 4, byrow = TRUE) X = PWO(design) D_effi_pwo(X)design <- matrix(c(4,2,3,1, 4,1,3,2, 3,4,2,1, 3,4,1,2, 3,2,1,4, 3,1,2,4, 2,4,3,1, 2,4,1,3, 2,1,3,4, 1,4,3,2, 1,4,2,3, 1,2,3,4), 12, 4, byrow = TRUE) X = PWO(design) D_effi_pwo(X)
Find optimum mixture proportions and optimal order of addition of the components
find_opt_target(m, model, target)find_opt_target(m, model, target)
m |
number of mixture components |
model |
a fitted model of class lm which fits a model for data from mixture order-of-addition experiment |
target |
desired target value of response variable |
returns optimum mixture proportions of the components and their optimal order-of-addition
data(fish) mixoofa.fit <- lm(y ~ -1 + (x1+x2+x3)^2 + z12+z13+z23, data = fish) summary(mixoofa.fit) find_opt_target(m = 3, mixoofa.fit, target = 2.75)data(fish) mixoofa.fit <- lm(y ~ -1 + (x1+x2+x3)^2 + z12+z13+z23, data = fish) summary(mixoofa.fit) find_opt_target(m = 3, mixoofa.fit, target = 2.75)
Data from an mixture order-of-addition experiment
data(fish)data(fish)
A data frame with 39 observations and following 7 variables.
yresponse variable
x1first mixture component proportion
x2second mixture component proportion
x3third mixture component proportion
z12first PWO variable
z13second PWO variable
z23third PWO variable
data(fish)data(fish)
obtain ANOVA table for a mixture order-of-addition experiment
mixoofa.anova(formula, response, nmix, mixvar, Zmat, caption)mixoofa.anova(formula, response, nmix, mixvar, Zmat, caption)
formula |
formula for mixture experiment |
response |
response variable |
nmix |
number of mixture components |
mixvar |
matrix representing mixture variables |
Zmat |
matrix containing PWO variables for the components |
caption |
caption for ANOVA table, default is blank |
an ANOVA table for mixture order-of-addition experiment
data(fish) m = 3 mixvar<-fish[, 1:(m+1)] Zmat<-fish[, (m+2): (m+1+choose(m,2))] mixoofa.anova(y ~ -1 + (x1+x2+x3)^2, response=fish$y, nmix=m, mixvar, Zmat=Zmat,caption="")data(fish) m = 3 mixvar<-fish[, 1:(m+1)] Zmat<-fish[, (m+2): (m+1+choose(m,2))] mixoofa.anova(y ~ -1 + (x1+x2+x3)^2, response=fish$y, nmix=m, mixvar, Zmat=Zmat,caption="")
construct an order-of-addition orthogonal array with m+1 components from an order-of-addition orthogonal array with m components
oofa.oa(design)oofa.oa(design)
design |
an order-of-addition orthogonal array with m components |
a component orthogonal array with m+1 components
design <- matrix(c(4,2,3,1, 4,1,3,2, 3,4,2,1, 3,4,1,2, 3,2,1,4, 3,1,2,4, 2,4,3,1, 2,4,1,3, 2,1,3,4, 1,4,3,2, 1,4,2,3, 1,2,3,4), 12, 4, byrow = TRUE) oofa.oa(design)design <- matrix(c(4,2,3,1, 4,1,3,2, 3,4,2,1, 3,4,1,2, 3,2,1,4, 3,1,2,4, 2,4,3,1, 2,4,1,3, 2,1,3,4, 1,4,3,2, 1,4,2,3, 1,2,3,4), 12, 4, byrow = TRUE) oofa.oa(design)
Construct an order-of-addition simplex centroid design with m components
oofa.scd(m)oofa.scd(m)
m |
number of components |
An order-of-addition simplex centroid design
oofa.scd(4)oofa.scd(4)
Construct an order-of-addition simplex lattice design with m components
oofa.sld(m)oofa.sld(m)
m |
number of components |
An order-of-addition simplex lattice design
oofa.sld(4)oofa.sld(4)
Obtain PWO matrix from a given design for order-of-addition experiments
PWO(design)PWO(design)
design |
a design for order-of-addition experiments |
PWO matrix
design <- matrix(c(4,2,3,1, 4,1,3,2, 3,4,2,1, 3,4,1,2, 3,2,1,4, 3,1,2,4, 2,4,3,1, 2,4,1,3, 2,1,3,4, 1,4,3,2, 1,4,2,3, 1,2,3,4), 12, 4, byrow = TRUE) PWO(design)design <- matrix(c(4,2,3,1, 4,1,3,2, 3,4,2,1, 3,4,1,2, 3,2,1,4, 3,1,2,4, 2,4,3,1, 2,4,1,3, 2,1,3,4, 1,4,3,2, 1,4,2,3, 1,2,3,4), 12, 4, byrow = TRUE) PWO(design)